#
# spec file for package python3-Babel
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           python3-Babel
Version:        1.3
Release:        5.6
Url:            http://babel.pocoo.org/
Summary:        Internationalization utilities
License:        BSD-3-Clause
Group:          Development/Languages/Python
Source:         http://pypi.python.org/packages/source/B/Babel/Babel-%{version}.tar.gz
# PATCH-FIX-OPENSUSE fix-timezone-test.patch (taken from upstream)
Patch0:         fix-timezone-test.patch
# PATCH-FIX-OPENSUSE skip-dst-tests.patch -- drop DST related tests (#156)
Patch1:         skip-dst-tests.patch
BuildRequires:  fdupes
BuildRequires:  python3-devel >= 3.3
BuildRequires:  python3-setuptools
# Test requirements:
BuildRequires:  python3-py >= 1.4.14
BuildRequires:  python3-pytest >= 2.3.5
BuildRequires:  python3-pytz
Requires:       python3-pytz
Requires(post): update-alternatives
Requires(postun): update-alternatives
BuildArch:      noarch

%description
A collection of tools for internationalizing Python applications.

%prep
%setup -q -n Babel-%{version}
%patch0 -p0
%patch1 -p1
sed -i "s/pybabel =/pybabel-%{py3_ver} =/" setup.py

%build
python3 setup.py build

%install
python3 setup.py install --prefix=%{_prefix} --root=%{buildroot}

mkdir -p %{buildroot}%{_sysconfdir}/alternatives
touch %{buildroot}%{_sysconfdir}/alternatives/pybabel
ln -sf %{_sysconfdir}/alternatives/pybabel %{buildroot}%{_bindir}/pybabel

%fdupes -s %{buildroot}%{python_sitelib}

%check
LC_ALL=C py.test tests

%pre
# Since /usr/bin/pybabel became ghosted to be used with update-alternatives, we have to get rid
# of the old binary resulting from the non-update-alternativies-ified package:
[ -h %{_bindir}/pybabel ] || rm -f %{_bindir}/pybabel

%post
update-alternatives --install %{_bindir}/pybabel pybabel %{_bindir}/pybabel-%{py3_ver} 30

%postun
if [ $1 -eq 0 ] ; then
    update-alternatives --remove pybabel %{_bindir}/pybabel-%{py3_ver}
fi

%files
%defattr(-,root,root,-)
%doc LICENSE CHANGES README
%ghost %{_sysconfdir}/alternatives/pybabel
%{_bindir}/pybabel
%{_bindir}/pybabel-%{py3_ver}
%{python3_sitelib}/*

%changelog
* Wed Jul  8 2015 toddrme2178@gmail.com
- Split documentation into separate package to avoid build loop
* Sat May 23 2015 benoit.monin@gmx.fr
- update project URL
- add skip-dst-tests.patch: drop DST related tests (workaround
  issue #156)
- fix update-alternatives
* Thu Jan 29 2015 arun@gmx.de
- Add fix-timezone-test.patch: already included upstream
- specfile:
  * updated copyright year
  * added patch
* Sat Nov  8 2014 Led <ledest@gmail.com>
- fix bashism in pre script
* Wed Oct 23 2013 toddrme2178@gmail.com
- Requires python3 >= 3.3
* Fri Oct 11 2013 p.drouand@gmail.com
- Set the u-a weight Babel binary to 30 instead of 20
* Wed Oct  2 2013 p.drouand@gmail.com
- Implement update-alternatives
- Properly build (and install) HTML documentation
* Sat Sep 28 2013 p.drouand@gmail.com
- Initial python3 support
* Fri Sep 27 2013 dmueller@suse.com
- update to 1.3.0:
  - support python 2.6, 2.7, 3.3+ and pypy - drop all other versions
  - use tox for testing on different pythons
  - Added support for the locale plural rules defined by the CLDR.
  - Added `format_timedelta` function to support localized formatting of
  relative times with strings such as "2 days" or "1 month" (ticket #126).
  - Fixed negative offset handling of Catalog._set_mime_headers (ticket #165).
  - Fixed the case where messages containing square brackets would break with
  an unpack error.
  - updated to CLDR 23
  - Make the CLDR import script work with Python 2.7.
  - Fix various typos.
  - Sort output of list-locales.
  - Make the POT-Creation-Date of the catalog being updated equal to
  POT-Creation-Date of the template used to update (ticket #148).
  - Use a more explicit error message if no option or argument (command) is
  passed to pybabel (ticket #81).
  - Keep the PO-Revision-Date if it is not the default value (ticket #148).
  - Make --no-wrap work by reworking --width's default and mimic xgettext's
  behaviour of always wrapping comments (ticket #145).
  - Add --project and --version options for commandline (ticket #173).
  - Add a __ne__() method to the Local class.
  - Explicitly sort instead of using sorted() and don't assume ordering
  (Jython compatibility).
  - Removed ValueError raising for string formatting message checkers if the
  string does not contain any string formattings (ticket #150).
  - Fix Serbian plural forms (ticket #213).
  - Small speed improvement in format_date() (ticket #216).
  - Fix so frontend.CommandLineInterface.run does not accumulate logging
  handlers (#227, reported with initial patch by dfraser)
  - Fix exception if environment contains an invalid locale setting (#200)
  - use cPickle instead of pickle for better performance (#225)
  - Only use bankers round algorithm as a tie breaker if there are two nearest
  numbers, round as usual if there is only one nearest number (#267, patch by
  Martin)
  - Allow disabling cache behaviour in LazyProxy (#208, initial patch from Pedro
  Algarvio)
  - Support for context-aware methods during message extraction (#229, patch
  from David Rios)
  - "init" and "update" commands support "--no-wrap" option (#289)
  - fix formatting of fraction in format_decimal() if the input value is a float
  with more than 7 significant digits (#183)
  - fix format_date() with datetime parameter (#282, patch from Xavier Morel)
  - fix format_decimal() with small Decimal values (#214, patch from George Lund)
  - fix handling of messages containing '\\n' (#198)
  - handle irregular multi-line msgstr (no "" as first line) gracefully (#171)
  - parse_decimal() now returns Decimals not floats, API change (#178)
  - no warnings when running setup.py without installed setuptools (#262)
  - modified Locale.__eq__ method so Locales are only equal if all of their
  attributes (language, territory, script, variant) are equal
  - resort to hard-coded message extractors/checkers if pkg_resources is
  installed but no egg-info was found (#230)
  - format_time() and format_datetime() now accept also floats (#242)
  - add babel.support.NullTranslations class similar to gettext.NullTranslations
  but with all of Babel's new gettext methods (#277)
  - "init" and "update" commands support "--width" option (#284)
  - fix 'input_dirs' option for setuptools integration (#232, initial patch by
  Étienne Bersac)
  - ensure .mo file header contains the same information as the source .po file
  (#199)
  - added support for get_language_name() on the locale objects.
  - added support for get_territory_name() on the locale objects.
  - added support for get_script_name() on the locale objects.
  - added pluralization support for currency names and added a '¤¤¤'
  pattern for currencies that includes the full name.
  - depend on pytz now and wrap it nicer.  This gives us improved support
  for things like timezone transitions and an overall nicer API.
  - Added support for explicit charset to PO file reading.
  - Added experimental Python 3 support.
  - Added better support for returning timezone names.
  - Don't throw away a Catalog's obsolete messages when updating it.
  - Added basic likelySubtag resolving when doing locale parsing and no
  match can be found.
- run tests
- use setuptools, not distribute
- add missing dependency on pytz
* Thu Sep  1 2011 saschpe@suse.de
- Fixed license to BSD-3-Clause (SPDX style)
* Thu Sep  1 2011 saschpe@suse.de
- Update to version 0.9.6:
  * Backport r493-494: documentation typo fixes.
  * Make the CLDR import script work with Python 2.7.
  * Fix various typos.
  * Fixed Python 2.3 compatibility (ticket #146, #233).
  * Sort output of list-locales.
  * Make the POT-Creation-Date of the catalog being updated equal to
    POT-Creation-Date of the template used to update (ticket #148).
  * Use a more explicit error message if no option or argument (command) is
    passed to pybabel (ticket #81).
  * Keep the PO-Revision-Date if it is not the default value (ticket #148).
  * Make --no-wrap work by reworking --width's default and mimic xgettext's
    behaviour of always wrapping comments (ticket #145).
  * Fixed negative offset handling of Catalog._set_mime_headers (ticket #165).
  * Add --project and --version options for commandline (ticket #173).
  * Add a __ne__() method to the Local class.
  * Explicitly sort instead of using sorted() and don't assume ordering
    (Python 2.3 and Jython compatibility).
  * Removed ValueError raising for string formatting message checkers if the
    string does not contain any string formattings (ticket #150).
  * Fix Serbian plural forms (ticket #213).
  * Small speed improvement in format_date() (ticket #216).
  * Fix number formatting for locales where CLDR specifies alt or draft
    items (ticket #217)
  * Fix bad check in format_time (ticket #257, reported with patch and tests by
    jomae)
  * Fix so frontend.CommandLineInterface.run does not accumulate logging
    handlers (#227, reported with initial patch by dfraser)
  * Fix exception if environment contains an invalid locale setting (#200)
- Renamed to python-Babel (from python-babel)
* Mon Dec 20 2010 saschpe@suse.de
- re-added dependency to python-setuptools
* Wed Dec 15 2010 saschpe@suse.de
- added documentation:
  * files: COPYING ChangeLog INSTALL.txt README.txt
  * HTML documentation
* Sat Dec 11 2010 saschpe@gmx.de
- re-generated spec file with py2pack:
  * now builds for Fedora and Mandriva
* Wed Sep  1 2010 jmatejek@novell.com
- added python-devel to buildrequires, to fix build on new python
  (because the package requires doctest, which requires unittest,
  which should probably both go into python-devel. (but this is
  subject to change))
- dropped check for obsolete SUSE version
* Sun Apr 25 2010 bitdealer@gmail.com
- Update to 0.9.5.
- Switch to noarch.
- Clean up spec.
